@@ -1,10 +1,10 @@
-//! A YAML 1.2 parser using greedy parsing algorithm with PEG atoms.
+//! A YAML 1.2 parser using a greedy parsing algorithm with PEG atoms.
 //!
-//! The major purpose of this crate is to let the user build their own YAML reader / builder / validator.
+//! The major purpose of this crate is to let the user build their own YAML reader/builder/validator.
 //!
-//! This parser is not ensure about YAML spec but almost functions are well-implemented.
+//! This parser is not ensuring about YAML spec but almost functions are well-implemented.
 //!
-//! The buffer reader has also not implemented, but the chunks can be read by sub-parsers.
+//! The buffer reader has also not been implemented, but sub-parsers can read the chunks.
 //!
 //! WARN: YAML 1.2 is compatible with [JSON (JavaScript Object Notation) format](https://www.json.org/),
 //! but not in strict mode.
@@ -13,7 +13,7 @@
 //!
 //! Function [`parse`] is used to parse YAML string into [`Node`] data structure,
 //! which has a data holder [`Yaml`].
-//! There also has multiple thread version corresponding to [`NodeRc`] / [`NodeArc`] and [`YamlRc`] / [`YamlArc`].
+//! There also has a multiple-threaded version corresponding to [`NodeRc`]/[`NodeArc`] and [`YamlRc`]/[`YamlArc`].
 //! To get back as string, please use [`dump`] function.
 //!
 //! There are also have some macros for building [`Node`] structure from Rust data.
@@ -23,28 +23,23 @@
 //!
 //! # Anchors
 //!
-//! The anchor system [`Anchor`] is implemented by using [`alloc::rc::Rc`] and [`alloc::sync::Arc`] as inner handler.
-//! Additionally, [`anchors!`] macro can used to create anchor visitor by yourself.
+//! The parser will replace the anchors during parsing.
 //!
 //! # Serialization and Deserialization
 //!
-//! Enable `serde` / `serde-std` feature to use `serde` crate.
-//! The crate provides a set of protocol traits to convert between custom Rust data.
-//! Please be aware that the additional fields will be discard when convert to a fix-sized structure.
+//! Enable `serde`/`serde-std` feature to use `serde` crate,
+//! which provides a set of protocol traits to convert between custom Rust data.
+//! Please be aware that the additional fields will be discarded when convert to a fix-sized structure.
 //! For example, the structure fields can be turned into map keys as well.
 //!
-//! On the other hand, the primitive types still able to transform to YAML data without serialization,
-//! according to `From` and `Into` traits.
-#![cfg_attr(
-    feature = "serde",
-    doc = "See [`crate::serde`] module for more information."
-)]
+//! On the other hand, the primitive types are still able to transform to YAML data without serialization,
+//! according to built-in `From` and `Into` traits.
 #![cfg_attr(doc_cfg, feature(doc_cfg))]
 #![cfg_attr(not(feature = "serde-std"), no_std)]
 #![warn(missing_docs)]
 extern crate alloc;
 
-pub use crate::{anchors::*, dumper::dump, indicator::*, node::*, parser::parse, yaml::*};
+pub use crate::{dumper::dump, indicator::*, node::*, parser::parse, yaml::*};
 
 /// Create [`Node`] items literally.
 ///
@@ -68,23 +63,6 @@ pub use crate::{anchors::*, dumper::dump, indicator::*, node::*, parser::parse,
 /// let m = vec![(NodeRc::from(1), NodeRc::from(2))];
 /// assert_eq!(node!({1 => 2}), m.into_iter().collect());
 /// ```
-///
-/// The [`Yaml::Alias`] is also supported by the syntax:
-///
-/// ```
-/// use yaml_peg::{node, Yaml};
-///
-/// assert_eq!(node!(Yaml::Alias("x".to_string())), node!(*"x"));
-/// ```
-///
-/// This macro is use [`Node`] by default,
-/// to specify them, a "rc" or "arc" prefix token can choose the presentation.
-///
-/// ```
-/// use yaml_peg::{node, NodeArc};
-///
-/// assert_eq!(node!(arc()), NodeArc::from(()));
-/// ```
 #[macro_export]
 macro_rules! node {
     (@[$v:expr; $n:expr]) => {{
@@ -119,29 +97,6 @@ macro_rules! node {
     };
 }
 
-/// Create a custom anchor visitor.
-///
-/// The anchor name should implement [`alloc::string::ToString`] trait.
-/// All items will convert to [`Node`] automatically.
-///
-/// ```
-/// use yaml_peg::{node, anchors};
-///
-/// let v = anchors![
-///     "my-boss" => node!({"name" => "Henry"}),
-/// ];
-/// assert_eq!(v["my-boss"]["name"], node!("Henry"));
-/// ```
-#[macro_export]
-macro_rules! anchors {
-    ($($k:expr => $v:expr),* $(,)?) => {{
-        extern crate alloc;
-        let v = alloc::vec![$(($k.to_string(), $crate::node!(@$v))),*];
-        v.into_iter().collect::<$crate::Anchor<_>>()
-    }};
-}
-
-mod anchors;
 pub mod dumper;
 mod indicator;
 mod node;
